==> navigine_sdk-1.2.1%2B3.tar.gz: lib/models/sub_location.dart <==
part of navigine_sdk;

class SubLocation {
  int id = 0;
  int location = 0;
  String name = "";
  String? svgFile = "";
  String? pngFile = "";
  String? jpgFile = "";
  double width = 0.0;
  double height = 0.0;
  double azimuth = 0.0;
  double latitude = 0.0;
  double longitude = 0.0;
  String? mapFile = "";
  String? updateFile = "";
  String? actionsFile = "";
  Uint8List? image;

  List<MeasureObject> measureList = [];
  List<Beacon> beacons = [];
  List<Venue> venues = [];
  List<Zone> zones = [];

  static SubLocation fromMap(var data) {
    SubLocation sl = SubLocation();
    sl.id = data["id"];
    sl.location = data["location"];
    sl.name = data["name"];
    sl.svgFile = data["svgFile"];
    sl.pngFile = data["pngFile"];
    sl.jpgFile = data["jpgFile"];
    sl.width = data["width"];
    sl.height = data["height"];
    sl.azimuth = data["azimuth"];
    sl.latitude = data["latitude"];
    sl.location = data["location"];
    sl.mapFile = data["mapFile"];
    sl.updateFile = data["updateFile"];
    sl.actionsFile = data["actionsFile"];
    sl.image = data["image"];

    sl.measureList = (data["measureList"] ?? [])
        .map<MeasureObject>((sl) => MeasureObject.fromMap(sl))
        .toList();

    sl.beacons =
        data["beacons"].map<Beacon>((sl) => Beacon.fromMap(sl)).toList();

    sl.venues = data["venues"].map<Venue>((sl) => Venue.fromMap(sl)).toList();

    sl.zones = data["zones"].map<Zone>((sl) => Zone.fromMap(sl)).toList();

    return sl;
  }

  static SubLocation fromAPIMap(var sl) {
    return SubLocation()
      ..id = sl["id"]
      ..name = sl["title"];
  }
}

==> navigine_sdk-1.2.4%2B3.tar.gz: lib/models/sub_location.dart <==
part of navigine_sdk;

class SubLocation {
  int id = 0;
  int location = 0;
  String name = "";
  num width = 0.0;
  num height = 0.0;
  num azimuth = 0.0;
  num latitude = 0.0;
  num longitude = 0.0;
  String? mapFile = "";
  String? updateFile = "";
  String? actionsFile = "";
  Uint8List? _image;

  Future<Uint8List> getImage() async {
    if (_image == null)
      _image = await _channel.invokeMethod(
        "getSublocationImage",
        {"subLocationId": id},
      );
    return _image!;
  }

  List<MeasureObject> measureList = [];
  List<Beacon> beacons = [];
  List<Venue> venues = [];
  List<Zone> zones = [];

  static SubLocation fromMap(var data) {
    SubLocation sl = SubLocation();
    sl.id = data["id"];
    sl.location = data["location"];
    sl.name = data["name"];
    sl.width = data["width"];
    sl.height = data["height"];
    sl.azimuth = data["azimuth"];
    sl.latitude = data["latitude"];
    sl.location = data["location"];
    sl.mapFile = data["mapFile"];
    sl.updateFile = data["updateFile"];
    sl.actionsFile = data["actionsFile"];

    sl.measureList = (data["measureList"] ?? [])
        .map<MeasureObject>((sl) => MeasureObject.fromMap(sl))
        .toList();

    sl.beacons =
        data["beacons"].map<Beacon>((sl) => Beacon.fromMap(sl)).toList();

    sl.venues = data["venues"].map<Venue>((sl) => Venue.fromMap(sl)).toList();

    sl.zones = data["zones"].map<Zone>((sl) => Zone.fromMap(sl)).toList();

    return sl;
  }

  static SubLocation fromAPIMap(var sl) {
    return SubLocation()
      ..id = sl["id"]
      ..name = sl["title"];
  }
}
